Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2544)

Unified Diff: content/public/browser/client_certificate_delegate.h

Issue 2898573002: Refactor client cert private key handling. (Closed)
Patch Set: removed no longer needed forward declaration Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/ssl/ssl_client_auth_handler.cc ('k') | content/public/browser/content_browser_client.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/client_certificate_delegate.h
diff --git a/content/public/browser/client_certificate_delegate.h b/content/public/browser/client_certificate_delegate.h
index d957fd995b3fc26665a5d49cbcae0011642d10c7..93f02826176cc7e12cc5eb1c96a9c6d017f1e625 100644
--- a/content/public/browser/client_certificate_delegate.h
+++ b/content/public/browser/client_certificate_delegate.h
@@ -8,6 +8,7 @@
#include "base/macros.h"
namespace net {
+class SSLPrivateKey;
class X509Certificate;
}
@@ -21,10 +22,12 @@ class ClientCertificateDelegate {
ClientCertificateDelegate() {}
virtual ~ClientCertificateDelegate() {}
- // Continue the request with |cert|. |cert| may be nullptr to continue without
- // supplying a certificate. This decision will be remembered for future
- // requests to the domain.
- virtual void ContinueWithCertificate(net::X509Certificate* cert) = 0;
+ // Continue the request with |cert| and matching |key|. |cert| may be nullptr
+ // to continue without supplying a certificate. This decision will be
+ // remembered for future requests to the domain.
+ virtual void ContinueWithCertificate(
+ scoped_refptr<net::X509Certificate> cert,
+ scoped_refptr<net::SSLPrivateKey> key) = 0;
private:
DISALLOW_COPY_AND_ASSIGN(ClientCertificateDelegate);
« no previous file with comments | « content/browser/ssl/ssl_client_auth_handler.cc ('k') | content/public/browser/content_browser_client.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698